@@ -1,19 +1,14 @@
-package Mojolicious::Plugin::BootstrapHelpers 0.0187 {
+use 5.20.0;
+use strict;
+use warnings;
 
-    use strict;
-    use warnings;
-    use true;
+our $VERSION = '0.0200'; # VERSION:
+# ABSTRACT: Type less bootstrap
+
+package Mojolicious::Plugin::BootstrapHelpers {
 
     use Mojo::Base 'Mojolicious::Plugin';
-
-    use List::AllUtils qw/uniq first_index/;
-    use Mojo::ByteStream;
-    use Mojo::Util 'xml_escape';
-    use Scalar::Util 'blessed';
-    use String::Trim;
     use Mojolicious::Plugin::BootstrapHelpers::Helpers;
-
-    use 5.20.0;
     use experimental 'postderef';
 
     sub register {
@@ -21,9 +16,17 @@ package Mojolicious::Plugin::BootstrapHelpers 0.0187 {
         my $app = shift;
         my $args = shift;
 
+        if(exists $args->{'short_strappings_prefix'}) {
+            $app->log->debug("'short_strappings_prefix' is deprecated. Use 'shortcut_prefix' instead");
+            $args->{'shortcut_prefix'} //= $args->{'short_strappings_prefix'};
+        }
+        if(exists $args->{'init_short_strappings'}) {
+            $app->log->debug("'init_short_strappings' is deprecated. Use 'init_shortcuts' instead");
+            $args->{'init_shortcuts'} //= $args->{'init_short_strappings'};
+        }
         my $tp = setup_prefix($args->{'tag_prefix'});
-        my $ssp = setup_prefix($args->{'short_strappings_prefix'});
-        my $init_short_strappings = $args->{'init_short_strappings'} //= 1;
+        my $ssp = setup_prefix($args->{'shortcut_prefix'});
+        my $init_shortcuts = $args->{'init_shortcuts'} //= 1;
 
         $app->helper($tp.'bootstrap' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstraps_bootstraps);
         $app->helper($tp.'table' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_table);
@@ -44,7 +47,7 @@ package Mojolicious::Plugin::BootstrapHelpers 0.0187 {
             $app->helper($tp.'icon' => \&Mojolicious::Plugin::BootstrapHelpers::Helpers::bootstrap_icon);
         }
 
-        if($init_short_strappings) {
+        if($init_shortcuts) {
             my @sizes = qw/xsmall small medium large/;
             my @contexts = qw/default active primary success info warning danger/;
             my @table = qw/striped bordered hover condensed responsive/;
@@ -68,15 +71,37 @@ package Mojolicious::Plugin::BootstrapHelpers 0.0187 {
     }
 
 }
+
+1;
+
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
 Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 
-=for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers"><img src="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master">&nbsp;</a>
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.20-brightgreen.svg" alt="Requires Perl 5.20" /> <a href="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers"><img src="https://api.travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.20](https://img.shields.io/badge/perl-5.20-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master)](https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers)
+
+=end markdown
+
+=head1 VERSION
+
+Version 0.0200, released 2015-11-24.
 
 =head1 SYNOPSIS
 
@@ -99,11 +124,9 @@ Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 
 =head1 STATUS
 
-This is an unstable work in progress. Backwards compatibility is currently not to be expected between releases.
+Relatively stable. This distribution will not be updated to support Bootstrap 4. There might be a separate distribution for that.
 
-Currently supported Bootstrap version: 3.3.1.
-
-Currently only Perl 5.20+ is supported (thanks to postderef).
+All examples are tested.
 
 =head1 DESCRIPTION
 
@@ -113,7 +136,6 @@ The goal is not to have tag helpers for everything, but for common use cases.
 
 All examples below (and more, see tests) is expected to work.
 
-
 =head2 How to use Bootstrap
 
 If you don't know what Bootstrap is, see L<http://www.getbootstrap.com/> for possible usages.
@@ -125,58 +147,56 @@ To get going quickly by using the official CDN you can use the following helpers
     # CSS
     %= bootstrap
 
-    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
+    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css">
 
     # or (if you want to use the theme)
     %= bootstrap 'theme'
 
-    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
-    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap-theme.min.css">
+    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css">
+    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap-theme.min.css">
 
     # And the javascript
     %= bootstrap 'js'
 
-    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
+    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
 
     # Or just:
     %= bootstrap 'all'
 
-    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
-    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap-theme.min.css">
-    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
+    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css">
+    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap-theme.min.css">
+    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
 
 It is also possible to automatically include jQuery (2.*)
 
     %= bootstrap 'jsq'
 
-    <script src="//code.jquery.com/jquery-2.1.1.min.js"></script>
-    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
+    <script src="//code.jquery.com/jquery-2.1.4.min.js"></script>
+    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
 
     %= bootstrap 'allq'
 
-    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css">
-    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap-theme.min.css">
-    <script src="//code.jquery.com/jquery-2.1.1.min.js"></script>
-    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
+    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css">
+    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap-theme.min.css">
+    <script src="//code.jquery.com/jquery-2.1.4.min.js"></script>
+    <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
 
+=head2 Shortcuts
 
-=head2 Strappings
-
-There are several shortcuts ("strappings") for applying context and size classes that automatically expands to the correct class depending
-on which tag it is applied to. For instance, if you apply the C<info> strapping to a panel, it becomes C<panel-info>, but when applied to a button it becomes C<btn-info>.
+There are several shortcuts for applying context and size classes that automatically expands to the correct class depending
+on which tag it is applied to. For instance, if you apply the C<info> shortcut to a panel, it becomes C<panel-info>, but when applied to a button it becomes C<btn-info>.
 
 You can use them in two different ways, but internally they are the same. These to lines are exactly identical:
 
+    # 'standalone shortcut'
     %= button 'Push me', primary
 
+    # 'longform shortcut'
     %= button 'Push me', __primary => 1
 
+For sizes, you can only use the longform (C<xsmall>, C<small>, C<medium> and C<large>). They are shortened to the Bootstrap type classes.
 
-
-For sizes, you can only use the longform (C<xsmall>, C<small>, C<medium> and C<large>) no matter if you use the short strapping form or not.
-They are shortened to the Bootstrap type classes.
-
-The following strappings are available:
+The following shortcuts are available:
 
    xsmall    default     striped       caret     right
    small     primary     bordered
@@ -185,18 +205,14 @@ The following strappings are available:
              warning     responsive
              danger
 
-Add two leading underscores if you don't want to use the short form.
+Add two leading underscores if you don't want to use the standalone form.
 
-See below for usage. B<Important:> You can't follow a short form strapping with a fat comma (C<=E<gt>>). The fat comma auto-quotes the strapping, and then it breaks.
+See below for usage. B<Important:> You can't follow a standalone shortcut with a fat comma (C<=E<gt>>). The fat comma auto-quotes the string on the left, and then it breaks.
 
-If there is no corresponding class for the element you add the strapping to it is silently not applied.
+If a shortcut you try to apply isn't available in that context, it is silently not applied.
 
-=begin html
-
-<p>The short form is recommended for readability, but it does setup several helpers in your templates.
-You can turn off the short forms, see <a href="#init_short_strappings">init_short_strappings</a>.</p>
-
-=end html
+=for html <p>The standalone form is recommended for readability, but it does setup several helpers in your templates.
+You can turn off this style, see <a href="#init_shortcuts">init_shortcuts</a>.</p>
 
 =head2 Syntax convention
 
@@ -206,7 +222,7 @@ In the syntax sections below the following conventions are used:
     $name           Any string
     %name           One or more key-value pairs, written as:
                       key => 'value', key2 => 'value2'
-                         or, if you use short form strappings:
+                         or, if you use standalone shortcuts:
                       primary, large
     $key => [...]   Both of these are array references where the ordering of strings
     key  => [...]     are significant, for example:
@@ -220,7 +236,6 @@ In the syntax sections below the following conventions are used:
                       button groups that contain buttons. Using this syntax makes the important parts clearer.
                       The pipes are not part of the actual syntax.
 
-
 Ordering between two hashes that follows each other is also not significant.
 
 B<About C<%has>>
@@ -229,7 +244,7 @@ The following applies to all C<%has> hashes below:
 
 =over 4
 
-=item * They refer to any html attributes and/or strappings to apply to the current element.
+=item * They refer to any html attributes and/or shortcuts to apply to the current element.
 
 =item * When helpers are nested, all occurrencies are change to tag-specific names, such as C<%panel_has>.
 
@@ -286,8 +301,7 @@ Mandatory. It sets the C<href> on the link. L<url_for|Mojolicious::Controller#ur
 
 B<C<%link_has>>
 
-Which strappings are available varies depending on context.
-
+Which shortcuts are available varies depending on context.
 
 =head3 |item|
 
@@ -319,6 +333,65 @@ So, a submenu item can be one of three things:
 
 See L</"Dropdowns">, L</"Button groups"> and L</"Navbars"> for examples.
 
+=head1 EXAMPLES
+
+All examples below, and more, are included in html files in C</examples>. They are also available on github:
+
+=over 4
+
+=item *
+
+L<Badges|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/badge-1.html>
+
+=item *
+
+L<Include bootstrap|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/bootstrap-1.html>
+
+=item *
+
+L<Buttons|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/button-1.html>
+
+=item *
+
+L<Button groups|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/button_group-1.html>
+
+=item *
+
+L<Dropdowns|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/dropdown-1.html>
+
+=item *
+
+L<Form groups|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/formgroup-1.html>
+
+=item *
+
+L<Icons|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/icon-1.html>
+
+=item *
+
+L<Input groups|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/input_group-1.html>
+
+=item *
+
+L<Navs|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/nav-1.html>
+
+=item *
+
+L<Navbars|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/navbar-1.html>
+
+=item *
+
+L<Panels|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/panel-1.html>
+
+=item *
+
+L<Tables|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/table-1.html>
+
+=item *
+
+L<Toolbars|http://htmlpreview.github.io/?https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers/blob/master/examples/toolbar-1.html>
+
+=back
 
 =head1 HELPERS
 
@@ -334,45 +407,34 @@ B<C<$text>>
 
 Mandatory. If it is C<undef> no output is produced.
 
-
-B<Available strappings>
+B<Available shortcuts>
 
 C<right> applies C<.pull-right>.
 
-
 =head3 Examples
 
 
+
+=begin html
+
+A basic badge:
+
+=end html
+
     <%= badge '3' %>
 
     <span class="badge">3</span></a>
 
 =begin html
 
-<p>
-A basic badge.
-
-</p>
+A right aligned badge with a data attribute:
 
 =end html
 
-
     <%= badge '4', data => { custom => 'yes' }, right %>
 
     <span class="badge pull-right" data-custom="yes">4</span>
 
-=begin html
-
-<p>
-A right aligned badge with a data attribute.
-
-</p>
-
-=end html
-
-
-
-
 =head2 Buttons
 
 L<Bootstrap documentation|http://getbootstrap.com/css/#buttons>
@@ -394,8 +456,7 @@ basically L<link_to|Mojolicious::Plugin::TagHelpers#link_to> with Bootstrap clas
 
 Not available for C<submit_button>.
 
-
-B<Available strappings>
+B<Available shortcuts>
 
 C<default> C<primary> C<success> C<info> C<warning> C<danger> C<link> applies the various C<.btn-*> classes.
 
@@ -405,54 +466,47 @@ C<active> C<block> applies the C<.active> and C<.block> classes.
 
 C<disabled> applies the C<.disabled> class if the generated element is an C<E<lt>aE<gt>>. On a C<E<lt>buttonE<gt>> it applies the C<disabled="disabled"> attribute.
 
-
 =head3 Examples
 
 
+
+=begin html
+
+An ordinary button, with applied shortcuts:
+
+=end html
+
     %= button 'The example 5' => large, warning
 
     <button class="btn btn-lg btn-warning" type="button">The example 5</button>
 
 =begin html
 
-<p>
-An ordinary button, with applied strappings.
-
-</p>
+With a url the button turns into a link:
 
 =end html
 
-
     %= button 'The example 1' => ['http://www.example.com/'], small
 
     <a class="btn btn-default btn-sm" href="http://www.example.com/">The example 1</a>
 
 =begin html
 
-<p>
-With a url the button turns into a link.
-
-</p>
+A submit button for use in forms. It overrides the build-in submit_button helper:
 
 =end html
 
-
     %= submit_button 'Save 2', primary
 
     <button class="btn btn-primary" type="submit">Save 2</button>
 
-=begin html
-
-<p>
-A submit button for use in forms. It overrides the build-in submit_button helper.
-
-</p>
-
-=end html
-
+    %= button 'Loop', active
 
+    <button class="active btn btn-default" type="button">Loop</button>
 
+    %= button 'Loop', block
 
+    <button class="block btn btn-default" type="button">Loop</button>
 
 =head2 Button groups
 
@@ -493,6 +547,13 @@ Giving a button an C<items> array reference consisting of one or many C<|item|>
 =head3 Examples
 
 
+
+=begin html
+
+A basic button group:
+
+=end html
+
     <%= buttongroup
         buttons => [
             ['Button 1'],
@@ -509,14 +570,10 @@ Giving a button an C<items> array reference consisting of one or many C<|item|>
 
 =begin html
 
-<p>
-A basic button group.
-
-</p>
+Nested button group. Note that the <code>small</code> shortcut is only necessary once. The same classes are automatically applied to the nested <code>.btn-group</code>:
 
 =end html
 
-
     <%= buttongroup small,
         buttons => [
             ['Button 1'],
@@ -549,14 +606,10 @@ A basic button group.
 
 =begin html
 
-<p>
-Nested button group. Note that the <code>small</code> strapping is only necessary once. The same classes are automatically applied to the nested <code>.btn-group</code>.
-
-</p>
+Nested button group, with the <code>vertical</code> shortcut:
 
 =end html
 
-
     <%= buttongroup vertical,
         buttons => [
             ['Button 1'],
@@ -589,14 +642,10 @@ Nested button group. Note that the <code>small</code> strapping is only necessar
 
 =begin html
 
-<p>
-Nested button group, with the <code>vertical</code> strapping.
-
-</p>
+Mix links and <code>dropup</code> menus in <code>justified</code> button groups:
 
 =end html
 
-
     <%= buttongroup justified,
         buttons => [
             ['Link 1', ['http://www.example.com/'] ],
@@ -627,14 +676,10 @@ Nested button group, with the <code>vertical</code> strapping.
 
 =begin html
 
-<p>
-Mix links and <code>dropup</code> menus in <code>justified</code> button groups.
-
-</p>
+Split button dropdowns uses the same syntax as any other multi-button dropdown. Set the <code>caret</code> button title to <code>undef</code>:
 
 =end html
 
-
     <%= buttongroup
         buttons => [
             ['Link 1', ['http://www.example.com/'] ],
@@ -663,14 +708,10 @@ Mix links and <code>dropup</code> menus in <code>justified</code> button groups.
 
 =begin html
 
-<p>
-Split button dropdowns uses the same syntax as any other multi-button dropdown. Set the <code>caret</code> button title to <code>undef</code>.
-
-</p>
+Using the simpler single-button button group dropdown syntax:
 
 =end html
 
-
     <%= buttongroup ['Default', caret, items  => [
                         ['Item 1', ['item1'] ],
                         ['Item 2', ['item2'] ],
@@ -709,18 +750,6 @@ Split button dropdowns uses the same syntax as any other multi-button dropdown.
         </ul>
     </div>
 
-=begin html
-
-<p>
-Using the shortcut to create single-button button group dropdowns.
-</p>
-
-=end html
-
-
-
-
-
 =head2 Button toolbars
 
 =head3 Syntax
@@ -738,6 +767,7 @@ A mandatory array reference of L<button groups|/"Button-groups">.
 =head3 Examples
 
 
+
     <%= toolbar id => 'my-toolbar',
                 groups => [
                     { buttons => [
@@ -768,9 +798,6 @@ A mandatory array reference of L<button groups|/"Button-groups">.
         </div>
     </div>
 
-
-
-
 =head2 Dropdowns
 
 =head3 Syntax
@@ -792,43 +819,48 @@ Mandatory array reference consisting of one or many C<|item|>. Read more under L
 
 =back
 
-
-B<Available strappings>
+B<Available shortcuts>
 
 C<caret> adds a C<E<lt>span class="caret"E<gt>E<lt>/span<E<gt>> element on the button.
 
-
 =head3 Examples
 
 
-    <%= dropdown
-         ['Dropdown 1', id => 'a_custom_id', right, items => [
-            ['Item 1', ['item1'] ],
-            ['Item 2', ['item2'] ],
-            [],
-            ['Item 3', ['item3'] ]
-         ] ] %>
 
-    <div class="dropdown">
-        <button class="btn btn-default dropdown-toggle" type="button" id="a_custom_id" data-toggle="dropdown">Dropdown 1</button>
-        <ul class="dropdown-menu dropdown-menu-right">
-            <li><a class="menuitem" href="item1" tabindex="-1">Item 1</a></li>
-            <li><a class="menuitem" href="item2" tabindex="-1">Item 2</a></li>
-            <li class="divider"></li>
-            <li><a class="menuitem" href="item3" tabindex="-1">Item 3</a></li>
-        </ul>
+=begin html
+
+By default, <code>tabindex</code> is set to <code>-1</code>:
+
+=end html
+
+    <div class="text-right">
+        <%= dropdown
+             ['Dropdown 1', id => 'a_custom_id', right, items => [
+                ['Item 1', ['item1'] ],
+                ['Item 2', ['item2'] ],
+                [],
+                ['Item 3', ['item3'] ]
+             ] ] %>
+    </div>
+
+    <div class="text-right">
+        <div class="dropdown">
+            <button class="btn btn-default dropdown-toggle" type="button" id="a_custom_id" data-toggle="dropdown">Dropdown 1</button>
+            <ul class="dropdown-menu dropdown-menu-right">
+                <li><a class="menuitem" href="item1" tabindex="-1">Item 1</a></li>
+                <li><a class="menuitem" href="item2" tabindex="-1">Item 2</a></li>
+                <li class="divider"></li>
+                <li><a class="menuitem" href="item3" tabindex="-1">Item 3</a></li>
+            </ul>
+        </div>
     </div>
 
 =begin html
 
-<p>
-By default, <code>tabindex</code> is set to <code>-1</code>...
-
-</p>
+...but it can be overridden:
 
 =end html
 
-
     <%= dropdown
          ['Dropdown 2', caret, large, primary, items => [
             ['Item 1', ['item1'], data => { attr => 2 } ],
@@ -855,17 +887,6 @@ By default, <code>tabindex</code> is set to <code>-1</code>...
         </ul>
     </div>
 
-=begin html
-
-<p>
-...but it can be overridden.
-</p>
-
-=end html
-
-
-
-
 =head2 Form groups
 
 L<Bootstrap documentation|http://getbootstrap.com/css/#forms>
@@ -936,10 +957,16 @@ Optional. If you prefer you can set C<value> in C<%input_has> instead. (But don'
 
 =back
 
-
 =head3 Examples
 
 
+
+=begin html
+
+The first item in the array ref is used for both <code>id</code> and <code>name</code>. Except...
+
+=end html
+
     %= formgroup 'Text test 1', text_field => ['test_text']
 
     <div class="form-group">
@@ -949,14 +976,10 @@ Optional. If you prefer you can set C<value> in C<%input_has> instead. (But don'
 
 =begin html
 
-<p>
-The first item in the array ref is used for both <code>id</code> and <code>name</code>. Except...
-
-</p>
+...if the input name (the first item in the text_field array ref) contains dashes -- those are replaced (in the <code>name</code>) to underscores:
 
 =end html
 
-
     %= formgroup 'Text test 4', text_field => ['test-text', large]
 
     <div class="form-group">
@@ -966,14 +989,10 @@ The first item in the array ref is used for both <code>id</code> and <code>name<
 
 =begin html
 
-<p>
-...if the input name (the first item in the text_field array ref) contains dashes -- those are replaced (in the <code>name</code>) to underscores.
-
-</p>
+An input with a value:
 
 =end html
 
-
     %= formgroup 'Text test 5', text_field => ['test_text', '200' ]
 
     <div class="form-group">
@@ -983,14 +1002,10 @@ The first item in the array ref is used for both <code>id</code> and <code>name<
 
 =begin html
 
-<p>
-An input with a value.
-
-</p>
+Note the difference with the earlier example. Here <code>large</code> is outside the <code>text_field</code> array reference, and therefore <code>.form-group-lg</code> is applied to the form group:
 
 =end html
 
-
     <form class="form-horizontal">
         %= formgroup 'Text test 6', text_field => ['test_text'], large, cols => { small => [2, 10] }
     </form>
@@ -1006,14 +1021,12 @@ An input with a value.
 
 =begin html
 
-<p>
-Note the difference with the earlier example. Here <code>large</code> is outside the <code>text_field</code> array reference, and therefore <code>.form-group-lg</code> is applied to the form group.
+A formgroup used in a <code>.form-horizontal</code> <code>form</code>:
 
-</p>
+(Note that in this context, <code>medium</code> and <code>large</code> are not shortcuts, but ordinary hash keys.)
 
 =end html
 
-
     %= formgroup 'Text test 8', text_field => ['test_text'], cols => { medium => [2, 10], small => [4, 8] }
 
     <div class="form-group">
@@ -1023,37 +1036,6 @@ Note the difference with the earlier example. Here <code>large</code> is outside
         </div>
     </div>
 
-=begin html
-
-<p>
-A formgroup used in a <code>.form-horizontal</code> <code>form</code>.
-
-(Note that in this context, <code>medium</code> and <code>large</code> are not short form strappings. Those don't take arguments.)
-
-</p>
-
-=end html
-
-
-    %= formgroup 'Text test 9', text_area => ['atextarea', 'default text']
-
-    <div class="form-group">
-        <label class="control-label" for="atextarea">Text test 9</label>
-        <textarea class="form-control" id="atextarea" name="atextarea">default text</textarea>
-    </div>
-
-=begin html
-
-<p>
-Textareas can also be used in formgroups.
-
-</p>
-
-=end html
-
-
-
-
 =head2 Icons
 
 This helper needs to be activated separately, see options below.
@@ -1069,16 +1051,13 @@ Mandatory. The specific icon you wish to create. Possible values depends on your
 =head3 Examples
 
 
+
     <%= icon 'copyright-mark' %>
     %= icon 'sort-by-attributes-alt'
 
     <span class="glyphicon glyphicon-copyright-mark"></span>
     <span class="glyphicon glyphicon-sort-by-attributes-alt"></span>
 
-
-
-
-
 =head2 Input groups
 
 =head3 Syntax
@@ -1122,6 +1101,13 @@ Creates a multi button buttongroup. See L<button groups|/"Button-groups"> for de
 =head3 Examples
 
 
+
+=begin html
+
+An input group with a checkbox:
+
+=end html
+
     <%= input input => { text_field => ['username'] },
               prepend => { check_box => ['agreed'] }
     %>
@@ -1133,14 +1119,10 @@ Creates a multi button buttongroup. See L<button groups|/"Button-groups"> for de
 
 =begin html
 
-<p>
-An input group with a checkbox.
-
-</p>
+A <code>large</code> input group with a radio button prepended and a string appended:
 
 =end html
 
-
     <%= input large,
               prepend => { radio_button => ['yes'] },
               input => { text_field => ['username'] },
@@ -1155,14 +1137,10 @@ An input group with a checkbox.
 
 =begin html
 
-<p>
-A <code>large</code> input group with a radio button prepended and a string appended.
-
-</p>
+An input group with a button:
 
 =end html
 
-
     <%= input input => { text_field => ['username'] },
               append => { button => ['Click me!'] },
     %>
@@ -1174,14 +1152,10 @@ A <code>large</code> input group with a radio button prepended and a string appe
 
 =begin html
 
-<p>
-An input group with a button.
-
-</p>
+An input group with a button dropdown appended. Note that <code>right</code> is manually applied:
 
 =end html
 
-
     <%= input input  => { text_field => ['username'] },
               append => { buttongroup => [['The button', caret, right, items => [
                                   ['Item 1', ['item1'] ],
@@ -1208,14 +1182,10 @@ An input group with a button.
 
 =begin html
 
-<p>
-An input group with a button dropdown appended. Note that <code>right</code> is manually applied.
-
-</p>
+An input group with a split button dropdown prepended:
 
 =end html
 
-
     <%= input input   => { text_field => ['username'] },
               prepend => { buttongroup => [
                               buttons => [
@@ -1249,17 +1219,6 @@ An input group with a button dropdown appended. Note that <code>right</code> is
         <input class="form-control" id="username" type="text" name="username" />
     </div>
 
-=begin html
-
-<p>
-An input group with a split button dropdown prepended.
-</p>
-
-=end html
-
-
-
-
 =head2 Navs
 
 =head3 Syntax
@@ -1287,6 +1246,13 @@ If present does the same as C<items> in L<dropdown|/"Dropdowns">. Also see L</"i
 =head3 Examples
 
 
+
+=begin html
+
+A simple pills navigation:
+
+=end html
+
     <%= nav pills => [
                 ['Item 1', ['#'] ],
                 ['Item 2', ['#'], active ],
@@ -1304,14 +1270,10 @@ If present does the same as C<items> in L<dropdown|/"Dropdowns">. Also see L</"i
 
 =begin html
 
-<p>
-A simple pills navigation.
-
-</p>
+A tab navigation with a menu:
 
 =end html
 
-
     <%= nav justified, id => 'my-nav', tabs => [
                 ['Item 1', ['#'] ],
                 ['Item 2', ['#'], active ],
@@ -1341,17 +1303,6 @@ A simple pills navigation.
         </li>
     </ul>
 
-=begin html
-
-<p>
-A tab navigation with a menu.
-</p>
-
-=end html
-
-
-
-
 =head2 Navbars
 
 =head3 Syntax
@@ -1374,7 +1325,7 @@ C<Navbars> are complex structures. They take the following arguments:
 
 B<C<inverse>>
 
-The C<inverse> strapping is currently outside the C<%navbar_has>. It applies the C<.navbar-inverse> class.
+The C<inverse> shortcut is placed outside the C<%navbar_has>. It applies the C<.navbar-inverse> class.
 
 B<C<header =E<gt> [ |link|, %navbar_has ]>>
 
@@ -1392,7 +1343,7 @@ Can take the following extra arguments:
 
 =over 4
 
-The C<hamburger> strapping creates the menu button for collapsed navbars.
+The C<hamburger> shortcut creates the menu button for collapsed navbars.
 
 B<C<toggler =E<gt> $collapse_id>>
 
@@ -1453,6 +1404,13 @@ Creates L<form groups|/"Form-groups">, L<input groups|/"Input-groups">, L<button
 =head3 Examples
 
 
+
+=begin html
+
+A simple navbar with a couple of links and a submenu:
+
+=end html
+
     <%= navbar header => ['The brand', ['#'], hamburger, toggler => 'bs-example-navbar-collapse-2'],
                nav => [ items => [
                        ['Link', ['#'] ],
@@ -1497,14 +1455,10 @@ Creates L<form groups|/"Form-groups">, L<input groups|/"Input-groups">, L<button
 
 =begin html
 
-<p>
-A simple navbar with a couple of links and a submenu.
-
-</p>
+This is (almost) identical to the <a href="http://getbootstrap.com/components/#navbar">Bootstrap documentation example</a>. The differences should be: The <code>form</code> has an action and the <code>input</code> has an <code>id</code> and a <code>name</code>:
 
 =end html
 
-
     <%= navbar header => ['Brand', ['#'], hamburger, toggler => 'collapse-4124'],
                nav => [ items => [
                        ['Link', ['#'], active ],
@@ -1594,16 +1548,6 @@ A simple navbar with a couple of links and a submenu.
         </div>
     </nav>
 
-=begin html
-
-<p>
-This is (almost) identical to the <a href="http://getbootstrap.com/components/#navbar">Bootstrap documentation example</a>. The differences should be: The <code>form</code> has an action, the <code>input</code> has <code>id</code> and <code>name</code>.
-</p>
-
-=end html
-
-
-
 =head2 Panels
 
 L<Bootstrap documentation|http://getbootstrap.com/components/#panels>
@@ -1622,10 +1566,16 @@ B<C<$body>>
 
 Optional (but panels are not much use without it). The html inside the C<panel>.
 
-
 =head3 Examples
 
 
+
+=begin html
+
+The class is set to <code>.panel-default</code>, by default:
+
+=end html
+
     %= panel
 
     <div class="panel panel-default">
@@ -1635,14 +1585,10 @@ Optional (but panels are not much use without it). The html inside the C<panel>.
 
 =begin html
 
-<p>
-The class is set to <code>.panel-default</code>, by default.
-
-</p>
+If you want a panel without title, set the title to <code>undef</code>:
 
 =end html
 
-
     %= panel undef ,=> begin
         <p>A short text.</p>
     %  end
@@ -1655,28 +1601,10 @@ The class is set to <code>.panel-default</code>, by default.
 
 =begin html
 
-<p>
-If you want a panel without title, set the title to <code>undef</code>.
-
-</p>
+A <code>success</code> panel with a header:
 
 =end html
 
-
-    %= panel 'The Header' => begin
-        <p>A short text.</p>
-    %  end
-
-    <div class="panel panel-default">
-        <div class="panel-heading">
-            <h3 class="panel-title">The Header</h3>
-        </div>
-        <div class="panel-body">
-            <p>A short text.</p>
-        </div>
-    </div>
-
-
     %= panel 'Panel 5', success, begin
         <p>A short text.</p>
     %  end
@@ -1690,10 +1618,6 @@ If you want a panel without title, set the title to <code>undef</code>.
         </div>
     </div>
 
-
-
-
-
 =head2 Tables
 
 L<Bootstrap documentation|http://getbootstrap.com/css/#tables>
@@ -1716,57 +1640,116 @@ B<C<panel =E<gt> { %panel_has }>>
 
 Optional if the table has a C<$title>, otherwise without use.
 
-
 =head3 Examples
 
 
 
 =begin html
 
-<p>
-
-</p>
+A basic table:
 
 =end html
 
     <%= table begin %>
-        <tr><td>Table 1</td></tr>
+        <thead>
+            <tr>
+                <th>th 1</th>
+                <th>th 2</th>
+        </thead>
+        <tbody>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+        </tbody>
     <% end %>
 
     <table class="table">
-        <tr><td>Table 1</td></tr>
+        <thead>
+            <tr>
+                <th>th 1</th>
+                <th>th 2</th>
+        </thead>
+        <tbody>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+        </tbody>
     </table>
 
 =begin html
 
-<p>
-A basic table.
-
-</p>
+Several classes applied to the table:
 
 =end html
 
-
     %= table hover, striped, condensed, begin
-        <tr><td>Table 2</td></tr>
+        <thead>
+            <tr>
+                <th>th 1</th>
+                <th>th 2</th>
+        </thead>
+        <tbody>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+        </tbody>
     %  end
 
     <table class="table table-condensed table-hover table-striped">
-        <tr><td>Table 2</td></tr>
+        <thead>
+            <tr>
+                <th>th 1</th>
+                <th>th 2</th>
+        </thead>
+        <tbody>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+            <tr>
+                <td>Cell 1</td>
+                <td>Cell 2</td>
+            </tr>
+        </tbody>
     </table>
 
 =begin html
 
-<p>
-Several classes applied to the table.
-
-</p>
+A <code>condensed</code> table with an <code>id</code> wrapped in a <code>success</code> panel:
 
 =end html
 
-
     %= table 'Heading Table 4', panel => { success }, condensed, id => 'the-table', begin
-        <tr><td>Table 4</td></tr>
+            <thead>
+                <tr>
+                    <th>th 1</th>
+                    <th>th 2</th>
+            </thead>
+            <tbody>
+                <tr>
+                    <td>Cell 1</td>
+                    <td>Cell 2</td>
+                </tr>
+                <tr>
+                    <td>Cell 1</td>
+                    <td>Cell 2</td>
+                </tr>
+            </tbody>
     %  end
 
     <div class="panel panel-success">
@@ -1774,31 +1757,32 @@ Several classes applied to the table.
             <h3 class="panel-title">Heading Table 4</h3>
         </div>
         <table class="table table-condensed" id="the-table">
-            <tr><td>Table 4</td></tr>
+            <thead>
+                <tr>
+                    <th>th 1</th>
+                    <th>th 2</th>
+            </thead>
+            <tbody>
+                <tr>
+                    <td>Cell 1</td>
+                    <td>Cell 2</td>
+                </tr>
+                <tr>
+                    <td>Cell 1</td>
+                    <td>Cell 2</td>
+                </tr>
+            </tbody>
         </table>
     </div>
 
-=begin html
-
-<p>
-A <code>condensed</code> table with an <code>id</code> wrapped in a <code>success</code> panel.
-
-</p>
-
-=end html
-
-
-
-
-
 =head1 OPTIONS
 
 Some options are available:
 
     $app->plugin('BootstrapHelpers', {
         tag_prefix => 'bs',
-        short_strappings_prefix => 'set',
-        init_short_strappings => 1,
+        shortcut_prefix => 'set',
+        init_shortcuts => 1,
         icons => {
             class => 'glyphicon'
             formatter => 'glyphicon-%s',
@@ -1825,22 +1809,21 @@ If the option is set to any other string, the prefix is that string. If you set
 
 =back
 
-=head2 short_strappings_prefix
+=head2 shortcut_prefix
 
 Default: C<undef>
 
-This is similar to C<tag_prefix>, but is instead applied to the short form strappings. The same rules applies.
+This is similar to C<tag_prefix>, but is instead applied to the standalone shortcuts. The same rules applies.
 
-
-=head2 init_short_strappings
+=head2 init_shortcuts
 
 Default: C<1>
 
-If you don't want the short form of strappings setup at all, set this option to a defined but false value.
+If you don't want the standalone shortcuts setup at all, set this option to a defined but false value.
 
-All functionality is available, but instead of C<warning> you must now use C<__warning =E<gt> 1>.
+All functionality is available, but instead of C<warning> you must now write C<__warning =E<gt> 1>.
 
-With short form turned off, sizes are still only supported in long form: C<__xsmall>, C<__small>, C<__medium> and C<__large>. The Bootstrap abbreviations (C<xs> - C<lg>) are not used.
+With standalone form turned off, sizes are still only supported in long form: C<__xsmall>, C<__small>, C<__medium> and C<__large>. The Bootstrap abbreviations (C<xs> - C<lg>) are not available.
 
 =head2 icons
 
@@ -1877,4 +1860,23 @@ L<Mojolicious::Plugin::BootstrapHelpers> is third party software, and is not end
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Mojolicious-Plugin-BootstrapHelpers>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
