@@ -1,35 +1,37 @@
-package Mojolicious::Plugin::BootstrapHelpers::Helpers 0.0187 {
+use strict;
+use warnings;
+use 5.20.0;
 
-    use strict;
-    use warnings;
-    use Mojo::Base 'Mojolicious::Plugin';
+our $VERSION = '0.0200'; # VERSION:
+# ABSTRACT: Supporting module
 
-    use List::AllUtils qw/uniq first_index/;
+package Mojolicious::Plugin::BootstrapHelpers::Helpers {
+
+    use List::MoreUtils qw/uniq first_index/;
     use Mojo::ByteStream;
     use Mojo::Util 'xml_escape';
     use Scalar::Util 'blessed';
     use String::Trim;
-#    use Data::Dump::Streamer 'Dumper';
     use String::Random;
-    use experimental qw/postderef signatures/; # requires 5.20
+    use experimental qw/postderef signatures/;
 
     sub bootstraps_bootstraps {
         my $c = shift;
         my $arg = shift;
 
-        my $css   = q{<link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.3.1/css/bootstrap.min.css">};
-        my $theme = q{<link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.3.1/css/bootstrap-theme.min.css">};
-        my $js    = q{<script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.1/js/bootstrap.min.js"></script>};
-        my $jq    = q{<script src="//code.jquery.com/jquery-2.1.1.min.js"></script>};
+        my $css   = q{<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css">};
+        my $theme = q{<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap-theme.min.css">};
+        my $js    = q{<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>};
+        my $jq    = q{<script src="https://code.jquery.com/jquery-2.1.4.min.js"></script>};
 
         return out(
               !defined $arg  ? $css
-            : $arg eq 'css'  ? $css . $theme
-            : $arg eq 'js'   ? $js
-            : $arg eq 'jsq'  ? $jq . $js
-            : $arg eq 'all'  ? $css . $theme . $js
-            : $arg eq 'allq' ? $css . $theme . $jq . $js
-            :                 ''
+            : $arg eq 'css'  ? join "\n" => $css, $theme
+            : $arg eq 'js'   ? join "\n" => $js
+            : $arg eq 'jsq'  ? join "\n" => $jq, $js
+            : $arg eq 'all'  ? join "\n" => $css, $theme, $js
+            : $arg eq 'allq' ? join "\n" => $css, $theme, $jq, $js
+            :                  ''
         );
     }
 
@@ -805,6 +807,8 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers 0.0187 {
             }
         }
 
+        #$attr->{'class'} = trim join ' ' => uniq sort @classes;
+        my %uniqs = ();
         $attr->{'class'} = trim join ' ' => uniq sort @classes;
 
         return $attr;
@@ -857,7 +861,7 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers 0.0187 {
     sub cleanup_attrs {
         my $hash = shift;
 
-        #* delete all strappings (__*)
+        #* delete all shortcuts (-> __*)
         map { delete $hash->{ $_ } } grep { substr($_, 0, 2) eq '__' } keys $hash->%*;
 
         #* delete all keys whose value is not a string
@@ -911,3 +915,38 @@ package Mojolicious::Plugin::BootstrapHelpers::Helpers 0.0187 {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mojolicious::Plugin::BootstrapHelpers::Helpers - Supporting module
+
+=head1 VERSION
+
+Version 0.0200, released 2015-11-24.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-mojolicious-plugin-bootstraphelpers>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Mojolicious-Plugin-BootstrapHelpers>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
